@@ -1,5 +1,6 @@
 import typing
-from httpx import AsyncClient, Auth, Client, Request, Response
+import httpx
+from httpx import Auth, Request, Response
 from authlib.oauth1 import (
     SIGNATURE_HMAC_SHA1,
     SIGNATURE_TYPE_HEADER,
@@ -7,7 +8,7 @@ from authlib.oauth1 import (
 from authlib.common.encoding import to_unicode
 from authlib.oauth1 import ClientAuth
 from authlib.oauth1.client import OAuth1Client as _OAuth1Client
-from .utils import extract_client_kwargs
+from .utils import build_request, extract_client_kwargs
 from ..base_client import OAuthError
 
 
@@ -19,10 +20,10 @@ class OAuth1Auth(Auth, ClientAuth):
         url, headers, body = self.prepare(
             request.method, str(request.url), request.headers, request.content)
         headers['Content-Length'] = str(len(body))
-        yield Request(method=request.method, url=url, headers=headers, content=body)
+        yield build_request(url=url, headers=headers, body=body, initial_request=request)
 
 
-class AsyncOAuth1Client(_OAuth1Client, AsyncClient):
+class AsyncOAuth1Client(_OAuth1Client, httpx.AsyncClient):
     auth_class = OAuth1Auth
 
     def __init__(self, client_id, client_secret=None,
@@ -33,7 +34,12 @@ class AsyncOAuth1Client(_OAuth1Client, AsyncClient):
                  force_include_body=False, **kwargs):
 
         _client_kwargs = extract_client_kwargs(kwargs)
-        AsyncClient.__init__(self, **_client_kwargs)
+        # app keyword was dropped!
+        app_value = _client_kwargs.pop('app', None)
+        if app_value is not None:
+            _client_kwargs['transport'] = httpx.ASGITransport(app=app_value)
+
+        httpx.AsyncClient.__init__(self, **_client_kwargs)
 
         _OAuth1Client.__init__(
             self, None,
@@ -75,7 +81,7 @@ class AsyncOAuth1Client(_OAuth1Client, AsyncClient):
         raise OAuthError(error_type, error_description)
 
 
-class OAuth1Client(_OAuth1Client, Client):
+class OAuth1Client(_OAuth1Client, httpx.Client):
     auth_class = OAuth1Auth
 
     def __init__(self, client_id, client_secret=None,
@@ -86,7 +92,12 @@ class OAuth1Client(_OAuth1Client, Client):
                  force_include_body=False, **kwargs):
 
         _client_kwargs = extract_client_kwargs(kwargs)
-        Client.__init__(self, **_client_kwargs)
+        # app keyword was dropped!
+        app_value = _client_kwargs.pop('app', None)
+        if app_value is not None:
+            _client_kwargs['transport'] = httpx.WSGITransport(app=app_value)
+
+        httpx.Client.__init__(self, **_client_kwargs)
 
         _OAuth1Client.__init__(
             self, self,
