@@ -26,7 +26,7 @@ class OAuth2Auth(AuthBase, TokenAuth):
             req.url, req.headers, req.body = self.prepare(
                 req.url, req.headers, req.body)
         except KeyError as error:
-            description = 'Unsupported token_type: {}'.format(str(error))
+            description = f'Unsupported token_type: {str(error)}'
             raise UnsupportedTokenTypeError(description=description)
         return req
 
@@ -64,6 +64,9 @@ class OAuth2Session(OAuth2Client, Session):
         values: "header", "body", "uri".
     :param update_token: A function for you to update token. It accept a
         :class:`OAuth2Token` as parameter.
+    :param leeway: Time window in seconds before the actual expiration of the
+        authentication token, that the token is considered expired and will
+        be refreshed.
     :param default_timeout: If settled, every requests will have a default timeout.
     """
     client_auth_class = OAuth2ClientAuth
@@ -79,7 +82,7 @@ class OAuth2Session(OAuth2Client, Session):
                  revocation_endpoint_auth_method=None,
                  scope=None, state=None, redirect_uri=None,
                  token=None, token_placement='header',
-                 update_token=None, default_timeout=None, **kwargs):
+                 update_token=None, leeway=60, default_timeout=None, **kwargs):
         Session.__init__(self)
         self.default_timeout = default_timeout
         update_session_configure(self, kwargs)
@@ -91,7 +94,7 @@ class OAuth2Session(OAuth2Client, Session):
             revocation_endpoint_auth_method=revocation_endpoint_auth_method,
             scope=scope, state=state, redirect_uri=redirect_uri,
             token=token, token_placement=token_placement,
-            update_token=update_token, **kwargs
+            update_token=update_token, leeway=leeway, **kwargs
         )
 
     def fetch_access_token(self, url=None, **kwargs):
@@ -106,5 +109,5 @@ class OAuth2Session(OAuth2Client, Session):
             if not self.token:
                 raise MissingTokenError()
             auth = self.token_auth
-        return super(OAuth2Session, self).request(
+        return super().request(
             method, url, auth=auth, **kwargs)
