@@ -38,6 +38,9 @@ class OAuth2Client:
         values: "header", "body", "uri".
     :param update_token: A function for you to update token. It accept a
         :class:`OAuth2Token` as parameter.
+    :param leeway: Time window in seconds before the actual expiration of the
+        authentication token, that the token is considered expired and will
+        be refreshed.
     """
     client_auth_class = ClientAuth
     token_auth_class = TokenAuth
@@ -52,7 +55,8 @@ class OAuth2Client:
                  token_endpoint_auth_method=None,
                  revocation_endpoint_auth_method=None,
                  scope=None, state=None, redirect_uri=None, code_challenge_method=None,
-                 token=None, token_placement='header', update_token=None, **metadata):
+                 token=None, token_placement='header', update_token=None, leeway=60,
+                 **metadata):
 
         self.session = session
         self.client_id = client_id
@@ -97,6 +101,8 @@ class OAuth2Client:
         }
         self._auth_methods = {}
 
+        self.leeway = leeway
+
     def register_client_auth_method(self, auth):
         """Extend client authenticate for token endpoint.
 
@@ -223,7 +229,7 @@ class OAuth2Client:
         self.token = token
         return token
 
-    def refresh_token(self, url, refresh_token=None, body='',
+    def refresh_token(self, url=None, refresh_token=None, body='',
                       auth=None, headers=None, **kwargs):
         """Fetch a new access token using a refresh token.
 
@@ -247,6 +253,9 @@ class OAuth2Client:
         if headers is None:
             headers = DEFAULT_HEADERS.copy()
 
+        if url is None:
+            url = self.metadata.get('token_endpoint')
+
         for hook in self.compliance_hook['refresh_token_request']:
             url, headers, body = hook(url, headers, body)
 
@@ -257,8 +266,10 @@ class OAuth2Client:
             url, refresh_token=refresh_token, body=body, headers=headers,
             auth=auth, **session_kwargs)
 
-    def ensure_active_token(self, token):
-        if not token.is_expired():
+    def ensure_active_token(self, token=None):
+        if token is None:
+            token = self.token
+        if not token.is_expired(leeway=self.leeway):
             return True
         refresh_token = token.get('refresh_token')
         url = self.metadata.get('token_endpoint')
